atomate.vasp.workflows.presets package — atomate 0.3 documentation

# atomate.vasp.workflows.presets package

## Submodules

## atomate.vasp.workflows.presets.core module

`atomate.vasp.workflows.presets.core.` `wf_bandstructure`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bandstructure_plus_boltztrap`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bandstructure_plus_hse`(structure, gap_only=True, c=None)

`atomate.vasp.workflows.presets.core.` `wf_bulk_modulus`(structure, c=None)

  Bulk modulus workflow from the given structure and config dict.

  Args:
    structure (Structure): input structure c (dict): workflow config dict
  Returns:
    Workflow

`atomate.vasp.workflows.presets.core.` `wf_dielectric_constant`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_elastic_constant`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_gibbs_free_energy`(structure, c=None)

  Gibbs free energy workflow from the given structure and config dict.

  Args:
    structure (Structure): input structure c (dict): workflow config dict
  Returns:
    Workflow

`atomate.vasp.workflows.presets.core.` `wf_piezoelectric_constant`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_raman_spectra`(structure, c=None)

  Raman spectra workflow from the given structure and config dict

  Args:
    structure (Structure): input structure c (dict): workflow config dict
  Returns:
    Workflow

`atomate.vasp.workflows.presets.core.` `wf_static`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_structure_optimization`(structure, c=None)

`atomate.vasp.workflows.presets.core.` `wf_thermal_expansion`(structure, c=None)

  Thermal expansion coefficient workflow from the given structure and config dict.

  Args:
    structure (Structure): input structure c (dict): workflow config dict
  Returns:
    Workflow

## Module contents